@@ -5,8 +5,9 @@ from laboro.validator import Validator
 
 
 class Module:
-  def __init__(self, filepath, args=None):
+  def __init__(self, filepath, store, args=None):
     self.filepath = filepath
+    self.store = store
     self.args = args
     self.specification = self._validate_spec()
     self._validate_args()
@@ -17,7 +18,8 @@ class Module:
       if len(args) > 1:
         logging.error("Using method with args instead of kwargs !")
         logging.warning("No argument checking will be done.")
-        func(*args[1:])
+        self.store[func.__name__] = func(*args[1:])
+        return self.store[func.__name__]
       else:
         try:
           method = func.__name__
@@ -26,7 +28,8 @@ class Module:
           Validator().validate_method_args(method, kwargs)
         except IndexError as err:
           raise LaboroError(f"UnknownMethodError: Unknown method: {method}") from err
-        func(self, **kwargs)
+        self.store[func.__name__] = func(self, **kwargs)
+        return self.store[func.__name__]
     return wrapper
 
   def _validate_spec(self):
